@@ -1,11 +1,21 @@
+"""
+Build CPython according to
+`the docs <https://devguide.python.org/setup/#macos-and-os-x>`_.
+Assumes Homebrew is installed.
+"""
+
 import os
 import subprocess
 import functools
 
+import autocommand
+
 
 @functools.lru_cache()
-def brew_prefix(name):
-    cmd = ['brew', '--prefix', name]
+def brew_prefix(name=None):
+    cmd = ['brew', '--prefix']
+    if name:
+        cmd.append(name)
     return subprocess.check_output(cmd, text=True).strip()
 
 
@@ -14,28 +24,23 @@ def require_libs():
     cmd = ['brew', 'list']
     installed = subprocess.check_output(cmd, text=True).strip().split()
     assert set(reqs) < set(installed), "Need {missing}".format(
-        missing=set(reqs) - set(installed))
+        missing=set(reqs) - set(installed)
+    )
 
 
+@autocommand.autocommand(__name__)
 def build_on_macOS():
     """
     Build cpython in the current directory on a mac with
     zlib and openssl installed.
     """
     require_libs()
-    deps = 'zlib', 'openssl@1.1', 'xz'
-    includes = [f'{prefix}/include' for prefix in map(brew_prefix, deps)]
-    libs = [f'{prefix}/lib' for prefix in map(brew_prefix, deps)]
+
     env = dict(
         os.environ,
-        CPPFLAGS=' '.join(f'-I{incl}' for incl in includes),
-        LDFLAGS=' '.join(f'-L{lib}' for lib in libs),
-    )
-    openssl = brew_prefix('openssl@1.1')
-    subprocess.run(
-        ['./configure', f'--with-openssl={openssl}'], env=env,
+        CPPFLAGS=f'-I{brew_prefix()}/include',
+        LDFLAGS=f'-I{brew_prefix()}/lib',
     )
+    cmd = ['./configure', f'--with-openssl={brew_prefix("openssl@1.1")}']
+    subprocess.run(cmd, env=env)
     subprocess.run('make')
-
-
-__name__ == '__main__' and build_on_macOS()
